OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Panell de control",
    "Dashboard app" : "Aplicació tauler",
    "Start your day informed\n\nThe Nextcloud Dashboard is your starting point of the day, giving you an overview of your upcoming appointments, urgent emails, chat messages, incoming tickets, latest tweets and much more! Users can add the widgets they like and change the background to their liking." : "Comença el dia informat\n\nEl tauler de control de Nextcloud és el vostre punt de partida del dia, que us ofereix una visió general de les vostres properes cites, correus electrònics urgents, missatges de xat, tickets entrants, els últims tuits i molt més! Els usuaris poden afegir els ginys que els agradin i canviar el fons al seu gust.",
    "\"{title} icon\"" : "\"icona {title}\"",
    "Customize" : "Personalitza",
    "Edit widgets" : "Edita els ginys",
    "Get more widgets from the App Store" : "Aconseguiu més widgets de la botiga d'aplicacions",
    "Weather service" : "Servei meteorològic",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "Per a la seva privadesa, les dades meteorològiques les sol·licita el seu servidor Nextcloud en el seu lloc perquè el servei meteorològic no rebi cap informació personal.",
    "Weather data from Met.no" : "Dades meteorològiques de Met.no",
    "geocoding with Nominatim" : "codis geogràfics amb Nominatim",
    "elevation data from OpenTopoData" : "dades d'altitud d'OpenTopoData",
    "Weather" : "Temps",
    "Status" : "Estat",
    "Good morning" : "Bon dia",
    "Good morning, {name}" : "Bon dia, {name}",
    "Good afternoon" : "Bona tarda",
    "Good afternoon, {name}" : "Bona tarda, {name}",
    "Good evening" : "Bona tarda",
    "Good evening, {name}" : "Bona nit, {name}",
    "Hello" : "Hola",
    "Hello, {name}" : "Hola {name}",
    "Start your day informed\n\nThe Nextcloud Dashboard is your starting point of the day, giving you an\noverview of your upcoming appointments, urgent emails, chat messages,\nincoming tickets, latest tweets and much more! Users can add the widgets\nthey like and change the background to their liking." : "Comença el dia informat\n\nEl tauler de control de Nextcloud és el vostre punt de partida del dia i us ofereix una\nvisió general de les vostres properes cites, correus electrònics urgents, missatges de xat,\ntiquets entrants, els darrers tuits i molt més! Els usuaris poden afegir els widgets\nque els agraden i canviar el fons al seu gust.",
    "Change background image" : "Canvia la imatge de fons",
    "Pick from Files" : "Trieu dels fitxers",
    "Default images" : "Imatges per defecte",
    "Plain background" : "Fons senzill",
    "Insert from {productName}" : "Insereix des de {productName}"
},
"nplurals=2; plural=(n != 1);");
